PyXMake Developer Guide: PyXMake.VTL.stm_make.pyx_app Class Reference

| PyXMake Developer Guide 1.0 PyXMake

Public Member Functions | Public Attributes | Static Public Attributes | List of all members
PyXMake.VTL.stm_make.pyx_app Class Reference
Inheritance diagram for PyXMake.VTL.stm_make.pyx_app:

## Public Member Functions
def | initialize_options (self)
def | finalize_options (self)
Public Member Functions inherited from PyXMake.VTL.stm_make._BaseCommandRunner
def | run (self)

## Public Attributes
| verbose
| source_path
| output_file_path
| mode
| scratch_path
| include
| dependency

## Static Public Attributes
string | description = "Compile a stand-alone application using PyInstaller."
list | user_options

## Detailed Description

    Base class for encapsulating command line arguments and build process.

Definition at line 86 of file stm_make.py.

## Member Function Documentation

## ◆ finalize_options()

def PyXMake.VTL.stm_make.pyx_app.finalize_options | ( |  | self | ) |

    Post-process options.

Definition at line 116 of file stm_make.py.

## ◆ initialize_options()

def PyXMake.VTL.stm_make.pyx_app.initialize_options | ( |  | self | ) |

    Set default values for options.

Definition at line 103 of file stm_make.py.

## Member Data Documentation

## ◆ user_options

list PyXMake.VTL.stm_make.pyx_app.user_options
| static

Initial value:
= [
# The format is (long option, short option, description).
('source-path=', None, 'path to the folder holding source files'),
('verbose=', None, 'controls the logging level (0 - Nothing, 2- Everything) Default: 0 - Nothing'),
('mode=', None, 'define application build mode (one directory or one file mode)'),
('scratch-path=', None, 'path to scratch folder where all temporary data is located during the build event'),
('output-file-path=', None, 'path to the output directory'),
]

Definition at line 94 of file stm_make.py.

The documentation for this class was generated from the following file:

- D:/03_Workspaces/01_Eclipse/pyx_core/PyXMake/VTL/stm_make.py